@@ -244,8 +244,8 @@ def fit_KPFM_curve(VG: list, phit: list, t: float, Cox: float, p0=[1,1,1]) -> np
     #Fit data setting to completely bounded parameters t and Cox since they
     #are provided from the user
     popt, pcov = curve_fit(fit_Poisson_Tip, xdata = phit, ydata = VG,
-                           p0 = p0, bounds=((-np.inf, -np.inf, -np.inf, t, Cox ),
-                                            (np.inf, np.inf, np.inf, t, Cox))
+                           p0 = p0, bounds=((-np.inf, -np.inf, -np.inf, t - 0.01*t, Cox- 0.01*Cox ),
+                                            (np.inf, np.inf, np.inf, t+ 0.01*t, Cox+0.01*Cox))
                            )
     
     err = np.sqrt(np.diag(pcov)) #calculate errors on parameters
